@@ -412,7 +412,7 @@ fake_mark_days (void)
 static void
 set_current_day (void)
 {
-	struct tm *tm;
+	struct tm tm;
 	time_t t;
 	GnomeCanvasItem *item;
 	int day_index;
@@ -420,16 +420,16 @@ set_current_day (void)
 	/* Set the date */
 
 	t = time (NULL);
-	tm = localtime (&t);
+	tm = *localtime (&t);
 
 	gnome_canvas_item_set (month_item,
-			       "year", tm->tm_year + 1900,
-			       "month", tm->tm_mon,
+			       "year", tm.tm_year + 1900,
+			       "month", tm.tm_mon,
 			       NULL);
 
 	/* Highlight current day */
 
-	day_index = gnome_month_item_day2index (GNOME_MONTH_ITEM (month_item), tm->tm_mday);
+	day_index = gnome_month_item_day2index (GNOME_MONTH_ITEM (month_item), tm.tm_mday);
 	item = gnome_month_item_num2child (GNOME_MONTH_ITEM (month_item), GNOME_MONTH_ITEM_DAY_LABEL + day_index);
 	gnome_canvas_item_set (item,
 			       "fill_color", color_spec_from_picker (COLOR_PROP_CURRENT_DAY_FG),
@@ -562,7 +562,7 @@ build_list_options_frame(void)
 {
 	GtkWidget *frame;
 	GtkWidget *vbox;
-	frame = gtk_frame_new (_("Show on TODO List:"));
+	frame = gtk_frame_new (_("Show on To Do List:"));
 	
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (frame), vbox);
@@ -592,7 +592,7 @@ build_style_list_options_frame(void)
 	GtkWidget *frame;
 	GtkWidget *vbox;
 
-	frame = gtk_frame_new (_("TODO List style options:"));
+	frame = gtk_frame_new (_("To Do List style options:"));
 	
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (frame), vbox);
@@ -615,10 +615,10 @@ create_todo_page (void)
 	GtkWidget *hbox;
 
 
-	frame = gtk_frame_new (_("Todo List Properties"));
+	frame = gtk_frame_new (_("To Do List Properties"));
 	gtk_container_set_border_width (GTK_CONTAINER (frame), GNOME_PAD_SMALL);
 	gnome_property_box_append_page (GNOME_PROPERTY_BOX (prop_win), frame,
-					gtk_label_new (_("Todo List")));
+					gtk_label_new (_("To Do List")));
 
 	/* first vbox*/
 	main_box = gtk_vbox_new(FALSE, GNOME_PAD);
