@@ -835,7 +835,7 @@ get_CardPhoto(VObject *o)
 		photo.size = vObjectIntegerValue(vo);
 		photo.data = malloc(photo.size);
 		memcpy (photo.data, vObjectAnyValue(o), photo.size);
-	} else {
+	} else if (vObjectValueType (o)) {
 		photo.size = strlen(str_val(o)) + 1;
 		photo.data = g_strdup(the_str);
 		free(the_str);
@@ -870,7 +870,7 @@ get_CardSound(VObject *o)
 		sound.size = vObjectIntegerValue(vo);
 		sound.data = malloc(sound.size);
 		memcpy (sound.data, vObjectAnyValue(o), sound.size);
-	} else {
+	} else if (vObjectValueType (o)) {
 		sound.size = strlen(str_val(o));
 		sound.data = g_strdup(the_str);
 		free(the_str);
@@ -899,10 +899,12 @@ card_create_from_vobject (VObject *vcrd)
 		propid = card_lookup_name(n);
 		
 		switch (propid) {
-		 case PROP_FNAME:
-			prop = &crd->fname.prop;
-			crd->fname.str = g_strdup(str_val(o));
-			free(the_str);
+		case PROP_FNAME:
+			if (vObjectValueType (o)) {
+				prop = &crd->fname.prop;
+				crd->fname.str = g_strdup(str_val(o));
+				free(the_str);
+			}
 			break;
 		 case PROP_NAME:
 			prop = &crd->name.prop;
@@ -913,11 +915,13 @@ card_create_from_vobject (VObject *vcrd)
 			crd->photo = get_CardPhoto(o);
 			break;
 		 case PROP_BDAY:
-			prop = &crd->bday.prop;
-			crd->bday = strtoCardBDay(str_val(o));
-			free(the_str);
+			if (vObjectValueType (o)) {
+				prop = &crd->bday.prop;
+				crd->bday = strtoCardBDay(str_val(o));
+				free(the_str);
+			}
 			break;
-		 case PROP_DELADDR:
+		case PROP_DELADDR:
 			{
 				CardDelAddr *c;
 				c = get_CardDelAddr(o);
@@ -925,112 +929,132 @@ card_create_from_vobject (VObject *vcrd)
 				crd->deladdr.l = g_list_append(crd->deladdr.l, c);
 			}
 			break;
-			
-		 case PROP_DELLABEL:
-			{
+		case PROP_DELLABEL:
+			if (vObjectValueType (o)) {
 				CardDelLabel *c;
 				c = get_CardDelLabel(o);
 				prop = &c->prop;
 				crd->dellabel.l = g_list_append(crd->dellabel.l, c);
 			}
 			break;
-			
-		 case PROP_PHONE:
-			{
+		case PROP_PHONE:
+			if (vObjectValueType (o)) {
 				CardPhone *c;
 				c = get_CardPhone(o);
 				prop = &c->prop;
 				crd->phone.l = g_list_append(crd->phone.l, c);
 			}
 			break;
-		 case PROP_EMAIL:
-			{
+		case PROP_EMAIL:
+			if (vObjectValueType (o)) {
 				CardEMail *c;
 				c = get_CardEMail(o);
 				prop = &c->prop;
 				crd->email.l = g_list_append(crd->email.l, c);
 			}
 			break;
-		 case PROP_MAILER:
-			prop = &crd->mailer.prop;
-			crd->mailer.str = g_strdup(str_val(o));
-			free(the_str);
+		case PROP_MAILER:
+			if (vObjectValueType (o)) {
+				prop = &crd->mailer.prop;
+				crd->mailer.str = g_strdup(str_val(o));
+				free(the_str);
+			}
 			break;
-		 case PROP_TIMEZN:
-			prop = &crd->timezn.prop;
-			crd->timezn = strtoCardTimeZone(str_val(o));
-			free(the_str);
+		case PROP_TIMEZN:
+			if (vObjectValueType (o)) {
+				prop = &crd->timezn.prop;
+				crd->timezn = strtoCardTimeZone(str_val(o));
+				free(the_str);
+			}
 			break;
-		 case PROP_GEOPOS:
-			prop = &crd->geopos.prop;
-			crd->geopos = strtoCardGeoPos(str_val(o));
+		case PROP_GEOPOS:
+			if (vObjectValueType (o)) {
+				prop = &crd->geopos.prop;
+				crd->geopos = strtoCardGeoPos(str_val(o));
+			}
 			break;
-		 case PROP_TITLE:
-			prop = &crd->title.prop;
-			crd->title.str = g_strdup(str_val(o));
-			free(the_str);
+		case PROP_TITLE:
+			if (vObjectValueType (o)) {
+				prop = &crd->title.prop;
+				crd->title.str = g_strdup(str_val(o));
+				free(the_str);
+			}
 			break;
-		 case PROP_ROLE:
-			prop = &crd->role.prop;
-			crd->role.str = g_strdup(str_val(o));
-			free(the_str);
+		case PROP_ROLE:
+			if (vObjectValueType (o)) {
+				prop = &crd->role.prop;
+				crd->role.str = g_strdup(str_val(o));
+				free(the_str);
+			}
 			break;
-		 case PROP_LOGO:
+		case PROP_LOGO:
 			prop = &crd->logo.prop;
 			crd->logo = get_CardPhoto(o);
 			break;
-		 case PROP_AGENT:
+		case PROP_AGENT:
 			crd->agent = card_create_from_vobject(o);
 			break;
-		 case PROP_ORG:
+		case PROP_ORG:
 			prop = &crd->org.prop;
 			crd->org = get_CardOrg(o);
 			break;
-		 case PROP_CATEGORIES:
-			prop = &crd->categories.prop;
-			crd->categories.str = g_strdup(str_val(o));
-			crd->categories.prop.encod = ENC_QUOTED_PRINTABLE;
-			free(the_str);
+		case PROP_CATEGORIES:
+			if (vObjectValueType (o)) {
+				prop = &crd->categories.prop;
+				crd->categories.str = g_strdup(str_val(o));
+				crd->categories.prop.encod = ENC_QUOTED_PRINTABLE;
+				free(the_str);
+			}
 			break;
-		 case PROP_COMMENT:
-			prop = &crd->comment.prop;
-			crd->comment.str = g_strdup(str_val(o));
-			crd->comment.prop.encod = ENC_QUOTED_PRINTABLE;
-			free(the_str);
+		case PROP_COMMENT:
+			if (vObjectValueType (o)) {
+				prop = &crd->comment.prop;
+				crd->comment.str = g_strdup(str_val(o));
+				crd->comment.prop.encod = ENC_QUOTED_PRINTABLE;
+				free(the_str);
+			}
 			break;
-		 case PROP_REV:
-			prop = &crd->rev.prop;
-			crd->rev = strtoCardRev(str_val(o));
-			free(the_str);
+		case PROP_REV:
+			if (vObjectValueType (o)) {
+				prop = &crd->rev.prop;
+				crd->rev = strtoCardRev(str_val(o));
+				free(the_str);
+			}
 			break;
 		 case PROP_SOUND:
 			prop = &crd->sound.prop;
 			crd->sound = get_CardSound(o);
 			break;
 		 case PROP_URL:
-			prop = &crd->url.prop;
-			crd->url.str = g_strdup(str_val(o));
-			free(the_str);
+			if (vObjectValueType (o)) {
+				prop = &crd->url.prop;
+				crd->url.str = g_strdup(str_val(o));
+				free(the_str);
+			}
 			break;
-		 case PROP_UID:
-			prop = &crd->uid.prop;
-			crd->uid.str = g_strdup(str_val(o));
-			free(the_str);
+		case PROP_UID:
+			if (vObjectValueType (o)) {
+				prop = &crd->uid.prop;
+				crd->uid.str = g_strdup(str_val(o));
+				free(the_str);
+			}
 			break;
 		 case PROP_VERSION:
-				{
-					char *str;
-					str = str_val(o);
-					if (strcmp(str, "2.1"))
-					  g_warning ("? < Version doesn't match.");
-					free(the_str);
-				}
+			if (vObjectValueType (o)) {
+				char *str;
+				str = str_val(o);
+				if (strcmp(str, "2.1"))
+					g_warning ("? < Version doesn't match.");
+				free(the_str);
+			}
 			break;
-		 case PROP_KEY:
-			prop = &crd->key.prop;
-			crd->key.type = get_key_type(o);
-			crd->key.data = g_strdup(str_val(o));
-			free(the_str);
+		case PROP_KEY:
+			if (vObjectValueType (o)) {
+				prop = &crd->key.prop;
+				crd->key.type = get_key_type(o);
+				crd->key.data = g_strdup(str_val(o));
+				free(the_str);
+			}
 			break;
 		 default:
 			g_warning("? < Property lookup returned invalid value.");
