@@ -610,7 +610,7 @@ extern void gnomecard_edit(GList *node)
 	gtk_box_pack_start(GTK_BOX(hbox), radio1, FALSE, FALSE, 0);
 	radio2 = gtk_radio_button_new_with_label(
 		gtk_radio_button_group(GTK_RADIO_BUTTON(radio1)),
-		_("X509"));
+		_("X.509"));
 	if (crd->key.prop.used && crd->key.type == KEY_X509)
 	  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(radio2), 1);
 	my_connect(radio2, "toggled", box, &crd->key.prop, PROP_KEY);
