@@ -46,6 +46,10 @@
 
 #include "columnhdrs.h"
 
+extern CORBA_Object
+impl_gnome_PIM_vCard_server__create(PortableServer_POA poa, 
+                                   CORBA_Environment * ev);
+
 #define NAME_COL_WIDTH 100
 #define ORG_COL_WIDTH 100
 #define PHONE_COL_WIDTH 100
