@@ -392,7 +392,7 @@ extern PhoneList *phonelist_create_edit_page (Card *crd, GnomePropertyBox *box)
 	gtk_container_add(GTK_CONTAINER(frame), hbox);
 	vbox = gtk_vbox_new(FALSE, GNOME_PAD_SMALL);
 	gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, GNOME_PAD_SMALL);
-	p->data = my_hbox_entry(vbox, "Number:", NULL);
+	p->data = my_hbox_entry(vbox, _("Number:"), NULL);
  	gtk_signal_connect(GTK_OBJECT(p->data), "changed",
 			   GTK_SIGNAL_FUNC(phonelist_data_changed), p);
 
